@@ -33,9 +33,10 @@
 #  define KSERVICE_DEPRECATED_NO_EXPORT KSERVICE_NO_EXPORT KSERVICE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KSERVICE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KSERVICE_NO_DEPRECATED
+#    define KSERVICE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
